Index: src/django_gheat/gheat/dataimport/kismet.py
===================================================================
--- src/django_gheat/gheat/dataimport/kismet.py	(revision 9818)
+++ src/django_gheat/gheat/dataimport/kismet.py	(revision 9819)
@@ -17,5 +17,5 @@
     raise IOError(e)
 
-  # Prepare new accespoints and measurements
+  # Prepare new accesspoints and measurements
   wnetworks = netxml_doc.findall('wireless-network')
 
@@ -55,5 +55,5 @@
   bssid_failed = defaultdict(int)
 
-  # Prepare new accespoints and measurements
+  # Prepare new accesspoints and measurements
   points = gpsxml_doc.findall('gps-point')
 

Index: src/django_gheat/gheat/dataimport/__init__.py
===================================================================
--- src/django_gheat/gheat/dataimport/__init__.py	(revision 9818)
+++ src/django_gheat/gheat/dataimport/__init__.py	(revision 9819)
@@ -74,7 +74,7 @@
 
 
-def import_accespoints(ap_pool, counters):
-  # Determine which Accespoints to add
-  bssid_list_present = Accespoint.objects.filter(mac__in=ap_pool.keys()).\
+def import_accesspoints(ap_pool, counters):
+  # Determine which Accesspoints to add
+  bssid_list_present = Accesspoint.objects.filter(mac__in=ap_pool.keys()).\
     values_list('mac', flat=True)
   bssid_list_insert = set(ap_pool.keys()) - set(bssid_list_present)
@@ -85,11 +85,11 @@
     for bssid in bssid_list_insert:
       ssid, encryption = ap_pool[bssid]
-      type = Accespoint.get_type_by_ssid(ssid)
+      type = Accesspoint.get_type_by_ssid(ssid)
       # Special trick in SSID ts avoid escaping in later stage
       item = str((bssid.upper(),ssid.replace('%','%%'),encryption,
-         Accespoint.get_type_by_ssid(ssid),
+         Accesspoint.get_type_by_ssid(ssid),
         get_organization_id_by_ssid(ssid)))
       sql_values.append(item)
-    counters['ap_added'] = bulk_sql('gheat_accespoint (`mac`, `ssid`,\
+    counters['ap_added'] = bulk_sql('gheat_accesspoint (`mac`, `ssid`,\
       `encryptie`, `type`, `organization_id`)',sql_values)
   return counters
@@ -104,5 +104,5 @@
   # Build mapping for meting import
   mac2id = {}
-  for mac,id in Accespoint.objects.filter(mac__in=bssid_list).\
+  for mac,id in Accesspoint.objects.filter(mac__in=bssid_list).\
     values_list('mac','id'):
     mac2id[mac] = int(id)
@@ -134,5 +134,5 @@
   if sql_values:
     counters['meting_added'] = bulk_sql('gheat_meting (`meetrondje_id`,\
-      `accespoint_id`, `latitude`, `longitude`, `signaal`)',sql_values)
+      `accesspoint_id`, `latitude`, `longitude`, `signaal`)',sql_values)
   return counters
 
@@ -186,5 +186,5 @@
 
   if ap_pool:
-    counters = import_accespoints(ap_pool, counters)
+    counters = import_accesspoints(ap_pool, counters)
   if client_pool:
     counters = import_clients(client_pool, counters)
@@ -192,5 +192,5 @@
     counters = import_metingen(meetrondje, meting_pool, counters)
 
-  logger.debug("summary accespoints: total:%(ap_total)-6s added:%(ap_added)-6s failed:%(ap_failed)-6s ignored:%(ap_ignored)-6s" % counters)
+  logger.debug("summary accesspoints: total:%(ap_total)-6s added:%(ap_added)-6s failed:%(ap_failed)-6s ignored:%(ap_ignored)-6s" % counters)
   logger.debug("summary client     : total:%(client_total)-6s added:%(client_added)-6s failed:%(client_failed)-6s ignored:%(client_ignored)-6s" % counters)
   logger.debug("summary metingen   : total:%(meting_total)-6s added:%(meting_added)-6s failed:%(meting_failed)-6s ignored:%(meting_ignored)-6s" % counters)